@@ -84,7 +84,7 @@ def queryhost(server, concurrent, timeout=5, port=123):
                                       af, socket.SOCK_DGRAM,
                                       socket.IPPROTO_UDP)
     except socket.gaierror as e:
-        log("lookup of %s failed, errno %d = %s" % (server, e[0], e[1]))
+        log("lookup of %s failed, errno %d = %s" % (server, e.args[0], e.args[1]))
         return []
     sockets = []
     packets = []
@@ -116,7 +116,7 @@ def queryhost(server, concurrent, timeout=5, port=123):
             s.sendto(packet, sockaddr)
         except socket.error as e:
             log("socket error on transmission: %s" % e)
-            raise SystemExit(1)
+            continue
         if debug >= 2:
             log("Sent to %s:" % (sockaddr[0],))
             ntp.packet.dump_hex_printable(packet)
@@ -336,6 +336,7 @@ if __name__ == '__main__':
                 elif switch in ("-M", "--steplimit"):
                     errmsg = "Error: -M parameter '%s' not a number\n"
                     steplimit = ntp.util.safeargcast(val, int, errmsg, usage)
+                    steplimit /= 1000.0
                 elif switch in ("-p", "--samples"):
                     errmsg = "Error: -p parameter '%s' not a number\n"
                     samples = ntp.util.safeargcast(val, int, errmsg, usage)
