@@ -53,6 +53,7 @@ NTP_LFP = 0x7     # NTP timestamp
 NTP_MODE = 0x8    # peer mode
 NTP_2BIT = 0x9    # leap bits
 NTP_FLOAT = 0xa   # Float value
+NTP_UPTIME = 0xb  # uptime in days H:M:S (no frac)
 
 
 class Ntpq(cmd.Cmd):
@@ -70,7 +71,7 @@ class Ntpq(cmd.Cmd):
         #  so I am leaving them, and possibly duplicating them.
         self.rawmode = False            # Flag which indicates raw mode output.
         self.directmode = False         # Flag for direct MRU output.
-        self.showhostnames = 1          # If & 1 false, display numeric IPs
+        self.showhostnames = 1          # If & 1, display names
         self.showunits = False          # If False, show old style float
         self.auth_delay = 20            # delay time (default 20msec)
         self.wideremote = False         # show wide remote names?
@@ -325,8 +326,7 @@ usage: help [ command ]
             # files a bug, Mode 6 never seems to generate those in
             # variable fetches.
             text = ntp.poly.polystr(session.response.replace(
-                ntp.poly.polybytes(",\r\n"),
-                ntp.poly.polybytes(",\n")))
+                ",\r\n", ",\n"))
         else:
             if not quiet:
                 self.say("status=%04x %s,\n"
@@ -394,6 +394,66 @@ function: set the primary receive time out
 usage: timeout [ msec ]
 """)
 
+    def collect_display2(self, variables):
+        "Query and display a collection of variables from the system."
+        try:
+            queried = self.session.readvar(0,
+                                           [v[0] for v in variables] +
+                                           [v[0] + '_r' for v in variables],
+                                           raw=True)
+        except ntp.packet.ControlException as e:
+            if ntp.control.CERR_UNKNOWNVAR == e.errorcode:
+                self.warn("Unknown variable.  Trying one at a time.")
+                varlist = [v[0] for v in variables] + \
+                          [v[0] + '_r' for v in variables]
+                items = []
+                for var in varlist:
+                    try:
+                        queried = self.session.readvar(0, [var],
+                                                       raw=True)
+                        for (name, (value, rawvalue)) in queried.items():
+                            items.append((name, (value, rawvalue)))
+                    except ntp.packet.ControlException as e:
+                        if ntp.control.CERR_UNKNOWNVAR == e.errorcode:
+                            items.append((var, "???"))
+                            continue
+                        raise e
+                queried = ntp.util.OrderedDict(items)
+            else:
+                self.warn(e.message)
+                return
+        except IOError as e:
+            self.warn(e.strerror)
+            return
+        if self.rawmode:
+            self.say(self.session.response)
+            return
+        try:
+            for (name, legend, fmt) in variables:
+                if name not in queried:
+                    continue
+                value = queried[name][0]
+                rawvalue = queried[name][1]
+                value2 = queried[name + '_r'][0]
+                rawvalue2 = queried[name + '_r'][1]
+                if fmt in (NTP_UINT, NTP_INT, NTP_FLOAT):
+                    if self.showunits:
+                        displayvalue = ntp.util.unitifyvar(rawvalue, name)
+                        displayvalue2 = ntp.util.unitifyvar(rawvalue2, name)
+                    else:
+                        displayvalue = value
+                        displayvalue2 = value2
+                    self.say("%13s \t%9d\t%9d\n" %
+                             (legend, displayvalue, displayvalue2))
+                elif fmt == NTP_UPTIME:
+                    self.say("%13s  %s\t%s\n" % (legend, ntp.util.prettyuptime(
+                        value), ntp.util.prettyuptime(value2)))
+                else:
+                    self.warn("unexpected vc type %s for %s, value %s"
+                              % (fmt, name, value, value2))
+        except KeyboardInterrupt:
+            self.warn("display interrupted")
+
     def collect_display(self, associd, variables, decodestatus):
         "Query and display a collection of variables from the system."
         try:
@@ -441,7 +501,7 @@ usage: timeout [ msec ]
                 value = queried[name][0]
                 rawvalue = queried[name][1]
                 if fmt in (NTP_ADD, NTP_ADP):
-                    if self.showhostnames[0]:
+                    if self.showhostnames & 1:  # if & 1, display names 
                         if self.debug:
                             self.say("DNS lookup begins...")
                         value = ntp.util.canonicalize_dns(
@@ -921,8 +981,10 @@ usage: writelist [ assocID ]
         associd = self.__assoc_valid(line)
         if associd >= 0:
             qtype = ntp.ntpc.TYPE_SYS if associd == 0 else ntp.ntpc.TYPE_PEER
+            silence = bool(len(line.split()) >= 2)
+            # Some scripts written for C ntpq need associd printed here
             self.__dolist(line.split()[1:], associd,
-                          ntp.control.CTL_OP_READVAR, qtype, quiet=True)
+                          ntp.control.CTL_OP_READVAR, qtype, quiet=silence)
 
     def help_readvar(self):
         self.say("""\
@@ -1112,6 +1174,16 @@ usage: pstats assocID
         self.say("""\
 function: obtain and print a list of the server's peers [IP version]
 usage: peers
+""")
+
+    def do_rpeers(self, line):
+        "obtain and print a list of the server's peers (dextral)"
+        self.__dopeers(showall=True, mode="rpeers")
+
+    def help_rpeers(self):
+        self.say("""\
+function: obtain and print a list of the server's peers (dextral)
+usage: rpeers
 """)
 
     def do_apeers(self, line):
@@ -1453,11 +1525,11 @@ usage: kerninfo
         "display system uptime and packet counts"
         sysstats = (
             ("ss_uptime", "uptime:               ", NTP_INT),
-            ("ss_reset", "sysstats reset:       ", NTP_INT),
+            ("ss_numctlreq", "control requests:     ", NTP_INT),
+            ("ss_reset", "sysstats reset:       ", NTP_UPTIME),
             ("ss_received", "packets received:     ", NTP_INT),
             ("ss_thisver", "current version:      ", NTP_INT),
             ("ss_oldver", "older version:        ", NTP_INT),
-            ("ss_numctlreq", "control requests:     ", NTP_INT),
             ("ss_badformat", "bad length or format: ", NTP_INT),
             ("ss_badauth", "authentication failed:", NTP_INT),
             ("ss_declined", "declined:             ", NTP_INT),
@@ -1540,21 +1612,21 @@ usage: authinfo
     def do_ntsinfo(self, _line):
         "display NTS authentication counters"
         ntsinfo = (
-   ("nts_client_send",           "NTS client sends:          ", NTP_INT),
-   ("nts_client_recv_good",      "NTS client recvs good:     ", NTP_INT),
-   ("nts_client_recv_bad",       "NTS client recvs w error:  ", NTP_INT),
-   ("nts_server_recv_good",      "NTS server recvs good:     ", NTP_INT),
-   ("nts_server_recv_bad",       "NTS server recvs w error:  ", NTP_INT),
-   ("nts_server_send",           "NTS server sends:          ", NTP_INT),
-   ("nts_cookie_make",           "NTS make cookies:          ", NTP_INT),
-   ("nts_cookie_decode",         "NTS decode cookies:        ", NTP_INT),
-   ("nts_cookie_decode_old",     "NTS decode cookies old:    ", NTP_INT),
-   ("nts_cookie_decode_too_old", "NTS decode cookies too old:", NTP_INT),
-   ("nts_cookie_decode_error",   "NTS decode cookies error:  ", NTP_INT),
-   ("nts_ke_probes_good",        "NTS KE probes good:        ", NTP_INT),
-   ("nts_ke_probes_bad",         "NTS KE probes_bad:         ", NTP_INT),
-   ("nts_ke_serves_good",        "NTS KE serves good:        ", NTP_INT),
-   ("nts_ke_serves_bad",         "NTS KE serves_bad:         ", NTP_INT),
+   ("nts_client_send",           "NTS client sends:          ", NTP_UINT),
+   ("nts_client_recv_good",      "NTS client recvs good:     ", NTP_UINT),
+   ("nts_client_recv_bad",       "NTS client recvs w error:  ", NTP_UINT),
+   ("nts_server_recv_good",      "NTS server recvs good:     ", NTP_UINT),
+   ("nts_server_recv_bad",       "NTS server recvs w error:  ", NTP_UINT),
+   ("nts_server_send",           "NTS server sends:          ", NTP_UINT),
+   ("nts_cookie_make",           "NTS make cookies:          ", NTP_UINT),
+   ("nts_cookie_decode",         "NTS decode cookies:        ", NTP_UINT),
+   ("nts_cookie_decode_old",     "NTS decode cookies old:    ", NTP_UINT),
+   ("nts_cookie_decode_too_old", "NTS decode cookies too old:", NTP_UINT),
+   ("nts_cookie_decode_error",   "NTS decode cookies error:  ", NTP_UINT),
+   ("nts_ke_probes_good",        "NTS KE client probes good: ", NTP_UINT),
+   ("nts_ke_probes_bad",         "NTS KE client probes bad:  ", NTP_UINT),
+   ("nts_ke_serves_good",        "NTS KE serves good:        ", NTP_UINT),
+   ("nts_ke_serves_bad",         "NTS KE serves bad:         ", NTP_UINT),
   )
         self.collect_display(associd=0, variables=ntsinfo, decodestatus=False)
 
