@@ -420,7 +420,7 @@ unpeer(
 	)
 {
 	mprintf_event(PEVNT_DEMOBIL, peer, "assoc %u", peer->associd);
-	restrict_source(&peer->srcadr, true, 0);
+	unrestrict_source(peer);
 	set_peerdstadr(peer, NULL);
 	peer_demobilizations++;
 	peer_associations--;
@@ -589,9 +589,7 @@ newpeer(
 
 	/*
 	 * If a peer is found, this would be a duplicate and we don't
-	 * allow that. This avoids duplicate ephemeral (broadcast/
-	 * multicast) and preemptible (manycast and pool) client
-	 * associations.
+	 * allow that.
 	 */
 	if (peer != NULL) {
 		DPRINT(2, ("newpeer(%s) found existing association\n", name));
@@ -689,14 +687,16 @@ newpeer(
 	/*
 	 * Put the new peer in the hash tables.
 	 */
-	if ((MDF_UCAST & cast_flags) && !(FLAG_LOOKUP & ctl->flags))
+	if ((MDF_UCAST & cast_flags) && !(FLAG_LOOKUP & ctl->flags)) {
+		/* simple server with numeric address */
 		peer_add_hash(peer);
+		restrict_source(peer);
+	}
 	hash = peer->associd & NTP_HASH_MASK;
 	LINK_SLIST(assoc_hash[hash], peer, aid_link);
 	assoc_hash_count[hash]++;
 	LINK_SLIST(peer_list, peer, p_link);
 
-	restrict_source(&peer->srcadr, false, 0);
 	mprintf_event(PEVNT_MOBIL, peer, "assoc %d", peer->associd);
 	DPRINT(1, ("newpeer: %s->%s mode %u vers %u poll %u %u flags 0x%x 0x%x mode %u key %08x\n",
 		   latoa(peer->dstadr), socktoa(&peer->srcadr), peer->hmode,
