@@ -155,7 +155,7 @@ lex_open(
 			free(stream);
 			msyslog(LOG_ERR, "CONFIG: failed to open \'%s\': %s",
 				path, strerror(errno));
-			exit(1);
+			stream = NULL;
 		}
 	}
 	return stream;
