@@ -24,6 +24,7 @@
 # include <sys/ioctl.h>
 #endif /* HAVE_SYS_IOCTL_H */
 #include <sched.h>
+#include <pthread.h>  /* For pthread_setschedparam() */
 #include <sys/mman.h>
 
 #include <termios.h>
@@ -104,7 +105,7 @@ static  void    close_all_beyond(int);
 static  void    close_all_except(int);
 
 
-#define ALL_OPTIONS "46abc:dD:f:gGhi:I:k:l:LmnNp:Pqr:Rs:t:u:U:Vw:xzZ"
+#define ALL_OPTIONS "46abc:dD:f:gGhi:I:k:l:LmnNp:P:qr:Rs:t:u:U:Vw:xzZ"
 static const struct option longoptions[] = {
     { "ipv4",		    0, 0, '4' },
     { "ipv6",		    0, 0, '6' },
@@ -434,7 +435,6 @@ set_process_priority(void)
 			 : "Attempt to set priority"
 				));
 # endif /* DEBUG */
-#ifdef HAVE_SCHED_SETSCHEDULER
 	if (need_priority) {
 		int pmax, pmin;
 		struct sched_param sched;
@@ -450,12 +450,11 @@ set_process_priority(void)
 			else
 				sched.sched_priority = config_priority;
 		}
-		if ( sched_setscheduler(0, SCHED_FIFO, &sched) == -1 )
-			msyslog(LOG_ERR, "INIT: sched_setscheduler(): %s", strerror(errno));
+		if ( pthread_setschedparam(pthread_self(), SCHED_FIFO, &sched) != 0 )
+			msyslog(LOG_ERR, "INIT: pthread_setschedparam(): %s", strerror(errno));
 		else
 			need_priority = false;
 	}
-#endif
 	if (need_priority)
 		msyslog(LOG_ERR, "INIT: set_process_priority: No way found to improve our priority");
 }
@@ -761,7 +760,8 @@ main(
 	    struct rlimit rlim;
 	    rlim.rlim_max = rlim.rlim_cur = RLIM_INFINITY;
 	    if (setrlimit(RLIMIT_MEMLOCK, &rlim) < 0)
-		msyslog(LOG_WARNING, "INIT: setrlimit() failed: not locking into RAM");
+		msyslog(LOG_DEBUG, "INIT: setrlimit(RLIMIT_CORE, [%ju, %ju]) failed",
+			(uintmax_t)rlim.rlim_cur, (uintmax_t)rlim.rlim_max);
 	    else
 #endif
 
