@@ -937,6 +937,9 @@ class PeerSummary:
             self.__header = self.__remote + \
                 "       local      ".ljust(self.refidwidth) + \
                 self.__common + "  disp"
+        elif self.displaymode == 'rpeers':
+            self.__header = ' st t when poll reach   delay   ' + \
+                            'offset   jitter refid           T remote'
         else:
             self.__header = self.__remote + \
                 "       refid      ".ljust(self.refidwidth) + \
@@ -1159,12 +1162,13 @@ class PeerSummary:
                 clock_name = srcadr
             else:
                 clock_name = ""
-        if self.wideremote and len(clock_name) > self.namewidth:
-            line += ("%c%s\n" % (c, clock_name))
-            line += (" " * (self.namewidth + 2))
-        else:
-            line += ("%c%-*.*s " % (c, self.namewidth, self.namewidth,
-                                    clock_name[:self.namewidth]))
+        if self.displaymode != "rpeers":
+            if self.wideremote and len(clock_name) > self.namewidth:
+                line += ("%c%s\n" % (c, clock_name))
+                line += (" " * (self.namewidth + 2))
+            else:
+                line += ("%c%-*.*s " % (c, self.namewidth, self.namewidth,
+                                        clock_name[:self.namewidth]))
         # Destination address, assoc ID or refid.
         assocwidth = 7 if self.displaymode == "apeers" else 0
         if "." not in dstadr_refid and ":" not in dstadr_refid:
@@ -1173,45 +1177,29 @@ class PeerSummary:
             visible = "..."
         else:
             visible = dstadr_refid
-        line += self.high_truncate(visible, self.refidwidth)
-        if self.displaymode == "apeers":
-            line += (" " * (self.refidwidth - len(visible) - assocwidth + 1))
-            line += ("%-6d" % (associd))
-        else:
-            line += (" " * (self.refidwidth - len(visible)))
+        if self.displaymode != "rpeers":
+            line += self.high_truncate(visible, self.refidwidth)
+            if self.displaymode == "apeers":
+                line += (" " * (self.refidwidth - len(visible) - assocwidth + 1))
+                line += ("%-6d" % (associd))
+            else:
+                line += (" " * (self.refidwidth - len(visible)))
         # The rest of the story
         if last_sync is None:
             last_sync = now
         jd = estjitter if have_jitter else estdisp
+        if self.showunits:
+            fini = lambda x : unitify(x, UNIT_MS)
+        elif saw6:
+            fini = lambda x : f8dot4(x)
+        else:
+            fini = lambda x : f8dot3(x)
         line += (
-            " %2ld %c %4.4s %4.4s  %3lo"
+            " %2ld %c %4.4s %4.4s  %3lo %s %s %s"
             % (stratum, ptype,
                PeerSummary.prettyinterval(last_sync),
-               PeerSummary.prettyinterval(poll_sec), reach))
-        if saw6:
-            if self.showunits:
-                line += (
-                    " %s %s %s" %
-                    (unitify(estdelay, UNIT_MS),
-                     unitify(estoffset, UNIT_MS),
-                     unitify(jd, UNIT_MS)))
-            else:
-                line += (
-                    " %s %s %s" %
-                    (f8dot4(estdelay), f8dot4(estoffset), f8dot4(jd)))
-        else:
-            # old servers only have 3 digits of fraction
-            # don't print a fake 4th digit
-            if self.showunits:
-                line += (
-                    " %s %s %s" %
-                    (unitify(estdelay, UNIT_MS),
-                     unitify(estoffset, UNIT_MS),
-                     unitify(jd, UNIT_MS)))
-            else:
-                line += (
-                    " %s %s %s" %
-                    (f8dot3(estdelay), f8dot3(estoffset), f8dot3(jd)))
+               PeerSummary.prettyinterval(poll_sec), reach,
+               fini(estdelay), fini(estoffset), fini(jd)))
         line += "\n"
         # for debugging both case
         # if srcadr != None and srchost != None:
@@ -1233,7 +1221,7 @@ class MRUSummary:
         self.debug = debug
         self.logfp = logfp
         self.now = None
-        self.showhostnames = showhostnames  # If not [0], display numeric IPs
+        self.showhostnames = showhostnames  # if & 1, display names 
         self.wideremote = wideremote
 
     header = " lstint avgint rstr r m v  count    score   drop rport remote address"
@@ -1269,7 +1257,7 @@ class MRUSummary:
             rscode = '.'
         (ip, port) = portsplit(entry.addr)
         try:
-            if not self.showhostnames & 1:
+            if not self.showhostnames & 1:  # if not & 1 display numeric IPs
                 dns = ip
             else:
                 dns = canonicalize_dns(ip)
@@ -1446,4 +1434,12 @@ except ImportError:  # pragma: no cover
             for key in self.__keys:
                 yield key
 
+
+def prettyuptime(uptime):
+    result = ''
+    if uptime >= 86400:
+        result += '%dD ' % (uptime // 86400)
+    result += '%02d:%02d:%02d' % ((uptime % 86400) //
+                                  3600, (uptime % 3600) // 60, uptime % 60)
+    return result
 # end
