@@ -38,7 +38,7 @@ then
     DISABLE_NTS="--disable-nts"
   fi
 else
-  if ! $PYTHON ../wafhelpers/tlscheck
+  if ! $PYTHON ../wafhelpers/tlscheck.py
   then
     DISABLE_NTS="--disable-nts"
   fi
