@@ -14,7 +14,7 @@ int main(void) {
 def check_libssl_tls13(ctx):
     ctx.check_cc(
       fragment=SNIP_LIBSSL_TLS13_CHECK,
-      use="SSL",
+      use="SSL CRYPTO",
       msg="Checking for OpenSSL with TLSv1.3 support",
     )
 
@@ -35,6 +35,6 @@ int main(void) {
 def check_openssl_bad_version(ctx):
     ctx.check_cc(
       fragment=SNIP_OPENSSL_BAD_VERSION_CHECK,
-      use="SSL",
+      use="SSL CRYPTO",
       msg="Checking for OpenSSL != 1.1.1a",
     )
